0.9.9 API documentation: vector_int2_precision.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
vector_int2_precision.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef vec< 2, int, highp > | highp_ivec2
| 2 components vector of high qualifier signed integer numbers. More...
typedef vec< 2, int, lowp > | lowp_ivec2
| 2 components vector of low qualifier signed integer numbers. More...
typedef vec< 2, int, mediump > | mediump_ivec2
| 2 components vector of medium qualifier signed integer numbers. More...

## Detailed Description

Core features

Definition in file vector_int2_precision.hpp.